@@ -443,6 +443,8 @@ standatalongremerge <- function(long, standata){ #merge an updated long portion
 
 standataFillTime <- function(standata, times, subject){
   long <- standatatolong(standata)
+  
+  if(any(!times %in% long$time)){ #if missing any times, add empty rows
   nlong <- do.call(rbind,
     lapply(subject, function(si){
       stimes <- times[!times %in% long$time[long$subject==si]]
@@ -456,11 +458,12 @@ standataFillTime <- function(standata, times, subject){
   nlong[,grep('^Y',colnames(nlong))] <- 99999
   nlong[,grep('^tdpreds',colnames(nlong))] <- 0
   
+  long <- rbind(long,nlong)
+  } #end empty rows addition
   
-  mlong <- rbind(long,nlong)
-  mlong <- mlong[order(mlong$subject,mlong$time),]
-  standatamerged <- standatalongremerge(long=mlong, standata=standata)
-  standatamerged$ndatapoints <- as.integer(nrow(mlong))
+  long <- long[order(long$subject,long$time),]
+  standatamerged <- standatalongremerge(long=long, standata=standata)
+  standatamerged$ndatapoints <- as.integer(nrow(long))
   return(standatamerged)
 }
 
@@ -988,7 +991,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
         if(optimcores==1) smf<-stan_reinitsf(sm,standatasml)
         
         
-        if(npars > 50 || nsubsets > 1) {
+        if(stochastic) {
           
           optimfit <- try(sgd(init, fitfunc = function(x) target(x),
             parsets=parsets,
@@ -996,11 +999,12 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
             whichignore = unlist(parsteps),nconvergeiter = 30,
             plot=plot, 
             itertol=tol*1000*stochasticTolAdjust,
-            worsecountconverge = 20,maxiter=ifelse(standata$ntipred > 0 && notipredsfirstpass, 500,5000)))
+            worsecountconverge = 20,
+            maxiter=ifelse(standata$ntipred > 0 && notipredsfirstpass, 500,5000)))
           
         }
         
-        if((npars <=50 && nsubsets ==1) || 'try-error' %in% class(optimfit)) {
+        if(!stochastic || 'try-error' %in% class(optimfit)) {
           optimfit <- mize(init, fg=mizelpg, max_iter=99999,
             method="L-BFGS",memory=100,
             line_search='Schmidt',c1=1e-10,c2=.9,step0='schmidt',ls_max_fn=999,
@@ -1018,10 +1022,9 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
         storedLp <- c()
         # if(length(parsteps) <1 && (standata$ntipred ==0 || notipredsfirstpass ==FALSE)) finished <- TRUE
         
-        
+        #update init, making sure ignored parameters still have values in init
         if(length(parsteps)>0) init[-unlist(parsteps)] = optimfit$par else init=optimfit$par
-        
-        
+
         if(length(parsteps) > 0){
           message('Freeing parameters...')
           finished <- FALSE
@@ -1030,10 +1033,12 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
             
             optimfit <- sgd(init, fitfunc = target,
               parsets=parsets,
+              nsubsets = nsubsets,
               itertol = tol*1000*stochasticTolAdjust,
               maxiter=5000,
               whichignore = unlist(parsteps),
-              ndatapoints=standata$ndatapoints,plot=plot)
+              plot=plot,worsecountconverge = 20)
+            
             
             if(length(parsteps)>0) init[-unlist(parsteps)] = optimfit$par else{
               finished <- TRUE
@@ -1151,7 +1156,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
           parrangetol=tol*100,
           maxiter=5000,
           whichignore = unlist(parsteps),
-          ndatapoints=standata$ndatapoints,plot=plot))
+          plot=plot))
       }
       
       
@@ -1559,15 +1564,18 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
           
           target_dens[[j]][is.na(target_dens[[j]])] <- -1e200
           if(all(target_dens[[j]] < -1e100)) stop('Could not sample from optimum! Try reparamaterizing?')
-          if(any(target_dens[[j]] > bestfit)){
-            oldfit <- bestfit
-            try2 <- TRUE
-            bestfit<-max(target_dens[[j]],na.rm=TRUE)
-            betterfit<-TRUE
-            init = samples[which(unlist(target_dens) == bestfit),]
-            message('Improved fit found - ', bestfit,' vs ', oldfit,' - restarting optimization')
-            break
-          }
+          
+          ### this was used to restart optimization in case a better logprob was found during sampling, but might have caused cran problems with break statement.
+          # if(any(target_dens[[j]] > bestfit)){
+          #   oldfit <- bestfit
+          #   try2 <- TRUE
+          #   bestfit<-max(target_dens[[j]],na.rm=TRUE)
+          #   betterfit<-TRUE
+          #   init = samples[which(unlist(target_dens) == bestfit),]
+          #   message('Improved fit found - ', bestfit,' vs ', oldfit,' - restarting optimization')
+          #   break
+          # }
+          
           targetvec <- unlist(target_dens)
           
           target_dens2 <- target_dens[[j]] #-max(target_dens[[j]],na.rm=TRUE) + max(prop_dens) #adjustment to get in decent range, doesnt change to prob
